@@ -37,14 +37,14 @@ if __name__ == '__main__':
 
     print("""
     Te damos la bienvenida a la interfaz interactiva de Minirobots!
-    Desde aquí podrás programar tu tortuga en tiempo real 😀
+    Desde aquí podrás programar tu tortuga en tiempo real :)
 
     Para ver la ayuda completa escribí
 
-        help(Turtle)⏎
+        help(Turtle)
 
     Si querés ver sólo la ayuda de alguna función específica,
     como por ejemplo 'forward', escribí
 
-        help(Turtle.forward)⏎
+        help(Turtle.forward)
     """)
